@@ -9,12 +9,15 @@ import (
 	"github.com/projectdiscovery/gologger"
 	"github.com/projectdiscovery/gologger/formatter"
 	"github.com/projectdiscovery/gologger/levels"
+	"github.com/projectdiscovery/proxify/pkg/logger"
 	"github.com/projectdiscovery/proxify/pkg/logger/elastic"
 	"github.com/projectdiscovery/proxify/pkg/logger/kafka"
 	"github.com/projectdiscovery/proxify/pkg/types"
+	errorutil "github.com/projectdiscovery/utils/errors"
 	fileutil "github.com/projectdiscovery/utils/file"
 	permissionutil "github.com/projectdiscovery/utils/permission"
 	updateutils "github.com/projectdiscovery/utils/update"
+	"gopkg.in/yaml.v2"
 )
 
 var (
@@ -24,6 +27,8 @@ var (
 // Options of the runner
 type Options struct {
 	OutputDirectory             string
+	OutputFile                  string // for storing the jsonl output
+	LoggerConfig                string
 	ConfigDir                   string
 	CertCacheSize               int
 	Verbosity                   types.Verbosity
@@ -67,7 +72,8 @@ func ParseOptions() (*Options, error) {
 
 	flagSet.CreateGroup("output", "Output",
 		// Todo:	flagSet.BoolVar(&options.Dump, "dump", true, "Dump HTTP requests/response to output file"),
-		flagSet.StringVarP(&options.OutputDirectory, "output", "o", "logs", "Output Directory to store HTTP proxy logs"),
+		flagSet.DynamicVarP(&options.OutputDirectory, "store-resposne", "sr", "proxify_logs", "store raw http request / response to output directory"),
+		flagSet.DynamicVarP(&options.OutputFile, "output", "o", "proxify_logs.jsonl", "output file to store proxify logs"),
 		flagSet.BoolVar(&options.DumpRequest, "dump-req", false, "Dump only HTTP requests to output file"),
 		flagSet.BoolVar(&options.DumpResponse, "dump-resp", false, "Dump only HTTP responses to output file"),
 		flagSet.BoolVarP(&options.OutputJsonl, "jsonl", "j", false, "write output in JSONL(ines) format"),
@@ -88,7 +94,7 @@ func ParseOptions() (*Options, error) {
 
 	flagSet.CreateGroup("network", "Network",
 		flagSet.StringVarP(&options.ListenAddrHTTP, "http-addr", "ha", "127.0.0.1:8888", "Listening HTTP IP and Port address (ip:port)"),
-		flagSet.StringVarP(&options.ListenAddrSocks5, "socks-addr", "sa", "127.0.0.1:10080", "Listening SOCKS IP and Port address (ip:port)"),
+		flagSet.DynamicVarP(&options.ListenAddrSocks5, "socks-addr", "sa", "127.0.0.1:10080", "Listening SOCKS IP and Port address (ip:port)"),
 		flagSet.StringVarP(&options.ListenDNSAddr, "dns-addr", "da", "", "Listening DNS IP and Port address (ip:port)"),
 		flagSet.StringVarP(&options.DNSMapping, "dns-mapping", "dm", "", "Domain to IP DNS mapping (eg domain:ip,domain:ip,..)"),
 		flagSet.StringVarP(&options.DNSFallbackResolver, "resolver", "r", "", "Custom DNS resolvers to use (ip:port)"),
@@ -102,23 +108,16 @@ func ParseOptions() (*Options, error) {
 
 	flagSet.CreateGroup("export", "Export",
 		flagSet.IntVar(&options.MaxSize, "max-size", math.MaxInt, "Max export data size (request/responses will be truncated)"),
-		flagSet.StringVar(&options.Elastic.Addr, "elastic-address", "", "elasticsearch address (ip:port)"),
-		flagSet.BoolVar(&options.Elastic.SSL, "elastic-ssl", false, "enable elasticsearch ssl"),
-		flagSet.BoolVar(&options.Elastic.SSLVerification, "elastic-ssl-verification", false, "enable elasticsearch ssl verification"),
-		flagSet.StringVar(&options.Elastic.Username, "elastic-username", "", "elasticsearch username"),
-		flagSet.StringVar(&options.Elastic.Password, "elastic-password", "", "elasticsearch password"),
-		flagSet.StringVar(&options.Elastic.IndexName, "elastic-index", "proxify", "elasticsearch index name"),
-		flagSet.StringVar(&options.Kafka.Addr, "kafka-address", "", "address of kafka broker (ip:port)"),
-		flagSet.StringVar(&options.Kafka.Topic, "kafka-topic", "proxify", "kafka topic to publish messages on"),
 	)
 
 	flagSet.CreateGroup("configuration", "Configuration",
 		flagSet.StringVar(&cfgFile, "config", "", "path to the proxify configuration file"),
+		flagSet.StringVarP(&options.LoggerConfig, "export-config", "ec", filepath.Join(homeDir, ".config", "proxify", logger.LoggerConfigFilename), "proxify export module configuration file"),
 		flagSet.StringVar(&options.ConfigDir, "config-directory", filepath.Join(homeDir, ".config", "proxify"), "override the default config path ($home/.config/proxify)"),
 		flagSet.IntVar(&options.CertCacheSize, "cert-cache-size", 256, "Number of certificates to cache"),
 		flagSet.StringSliceVarP(&options.Allow, "allow", "a", nil, "Allowed list of IP/CIDR's to be proxied", goflags.FileNormalizedStringSliceOptions),
 		flagSet.StringSliceVarP(&options.Deny, "deny", "d", nil, "Denied list of IP/CIDR's to be proxied", goflags.FileNormalizedStringSliceOptions),
-		flagSet.StringSliceVarP(&options.PassThrough, "passthrough", "pt", nil, "List of passthrough domains", goflags.NormalizedStringSliceOptions),
+		flagSet.StringSliceVarP(&options.PassThrough, "passthrough", "pt", nil, "List of passthrough domains", goflags.FileNormalizedStringSliceOptions),
 	)
 
 	silent, verbose, veryVerbose := false, false, false
@@ -149,6 +148,14 @@ func ParseOptions() (*Options, error) {
 		}
 	}
 
+	if err := options.createLoggerConfigIfNotExists(); err != nil {
+		return nil, err
+	}
+
+	if err := options.parseLoggerConfig(); err != nil {
+		return nil, err
+	}
+
 	// Read the inputs and configure the logging
 	options.configureVerbosity(silent, verbose, veryVerbose)
 	options.configureOutput()
@@ -171,7 +178,11 @@ func ParseOptions() (*Options, error) {
 			gologger.Info().Msgf("Current proxify version %v %v", version, updateutils.GetVersionDescription(version, latestVersion))
 		}
 	}
-
+	options.OutputJsonl = true
+	// if OutputFile is not set, set it to default
+	if options.OutputFile == "" {
+		options.OutputFile = "proxify_logs.jsonl"
+	}
 	return options, nil
 }
 
@@ -231,3 +242,44 @@ func (options *Options) configureOutput() {
 		gologger.DefaultLogger.SetFormatter(formatter.NewCLI(true))
 	}
 }
+
+// createLoggerConfigIfNotExists creates export-config if it doesn't exists
+func (options *Options) createLoggerConfigIfNotExists() error {
+	if fileutil.FileExists(options.LoggerConfig) {
+		return nil
+	}
+
+	config := &logger.Config{
+		Elastic: elastic.Options{},
+		Kafka:   kafka.Options{},
+	}
+	loggerConfigFile, err := os.Create(options.LoggerConfig)
+	if err != nil {
+		return errorutil.NewWithErr(err).Msgf("could not create config file")
+	}
+	defer loggerConfigFile.Close()
+
+	err = yaml.NewEncoder(loggerConfigFile).Encode(config)
+	return err
+}
+
+// parseLoggerConfig parses the logger configuration file
+func (options *Options) parseLoggerConfig() error {
+	var config logger.Config
+
+	data, err := os.ReadFile(options.LoggerConfig)
+	if err != nil {
+		return err
+	}
+
+	expandedData := os.ExpandEnv(string(data))
+	err = yaml.Unmarshal([]byte(expandedData), &config)
+	if err != nil {
+		return err
+	}
+
+	options.Kafka = config.Kafka
+	options.Elastic = config.Elastic
+
+	return nil
+}
