@@ -9,13 +9,13 @@ import (
 	fileutil "github.com/projectdiscovery/utils/file"
 )
 
-var ProxifyJsonlLogFile = "proxify.jsonl"
-
 // Options required for file export
 type Options struct {
 	// OutputFolder is the folder where the logs will be stored
 	OutputFolder string `yaml:"output-folder"`
-	OutputJsonl  bool   `yaml:"output-jsonl"`
+	// OutputFile is the file where the jsonl logs will be stored
+	OutputFile  string `yaml:"output-file"`
+	OutputJsonl bool   `yaml:"output-jsonl"`
 }
 
 // Client type for file based logging
@@ -26,11 +26,13 @@ type Client struct {
 // New creates and returns a new client for file based logging
 func New(option *Options) (*Client, error) {
 	client := &Client{options: option}
-	if err := fileutil.CreateFolder(option.OutputFolder); err != nil {
-		return client, err
+	if option.OutputFolder != "" {
+		if err := fileutil.CreateFolder(option.OutputFolder); err != nil {
+			return client, err
+		}
 	}
-	if option.OutputJsonl {
-		file, err := os.Create(filepath.Join(option.OutputFolder, ProxifyJsonlLogFile))
+	if option.OutputFile != "" {
+		file, err := os.Create(option.OutputFile)
 		if err != nil {
 			return client, err
 		}
@@ -41,18 +43,23 @@ func New(option *Options) (*Client, error) {
 
 // Store writes the log to the file
 func (c *Client) Save(data types.OutputData) error {
+	var err error
 	logFile := fmt.Sprintf("%s.%s", data.Name, "txt")
-	if c.options.OutputJsonl {
-		logFile = ProxifyJsonlLogFile
+	if c.options.OutputFolder != "" {
+		err = c.writeToFile(filepath.Join(c.options.OutputFolder, logFile), string(data.RawData))
 	}
-	// generate the file destination file name
-	destFile := filepath.Join(c.options.OutputFolder, logFile)
-	// if it's a response and file doesn't exist skip
-	f, err := os.OpenFile(destFile, os.O_APPEND|os.O_CREATE|os.O_WRONLY, 0644)
+	if c.options.OutputFile != "" && len(data.Data) > 0 {
+		err = c.writeToFile(c.options.OutputFile, data.DataString)
+	}
+	return err
+}
+
+func (c *Client) writeToFile(filepath, content string) error {
+	f, err := os.OpenFile(filepath, os.O_APPEND|os.O_CREATE|os.O_WRONLY, 0644)
 	if err != nil {
 		return err
 	}
 	// write to file
-	fmt.Fprint(f, data.DataString)
+	fmt.Fprint(f, content)
 	return f.Close()
 }
