@@ -22,13 +22,15 @@ import (
 )
 
 const (
-	dataWithNewLine    = "%s\n"
-	dataWithoutNewLine = "%s"
+	dataWithNewLine      = "%s\n"
+	dataWithoutNewLine   = "%s"
+	LoggerConfigFilename = "export-config.yaml"
 )
 
 type OptionsLogger struct {
 	Verbosity    types.Verbosity
 	OutputFolder string
+	OutputFile   string
 	DumpRequest  bool
 	DumpResponse bool
 	OutputJsonl  bool
@@ -78,17 +80,15 @@ func NewLogger(options *OptionsLogger) *Logger {
 
 		}
 	}
-	if options.OutputFolder != "" {
-		store, err := file.New(&file.Options{
-			OutputFolder: options.OutputFolder,
-			OutputJsonl:  options.OutputJsonl,
-		})
-		if err != nil {
-			gologger.Warning().Msgf("Error while creating file logger: %s", err)
-		} else {
-			logger.Store = append(logger.Store, store)
-
-		}
+	store, err := file.New(&file.Options{
+		OutputFolder: options.OutputFolder,
+		OutputJsonl:  options.OutputJsonl,
+		OutputFile:   options.OutputFile,
+	})
+	if err != nil {
+		gologger.Warning().Msgf("Error while creating file logger: %s", err)
+	} else {
+		logger.Store = append(logger.Store, store)
 	}
 
 	go logger.AsyncWrite()
@@ -121,9 +121,14 @@ func (l *Logger) AsyncWrite() {
 			}
 
 			outputdata.DataString = fmt.Sprintf(outputdata.Format, outputdata.Data)
+			if outputdata.Userdata.HasResponse {
+				outputdata.Format = "\n" + outputdata.Format
+			}
+			outputdata.RawData = []byte(fmt.Sprintf(outputdata.Format, outputdata.RawData))
 
 			if l.options.MaxSize > 0 {
 				outputdata.DataString = stringsutil.Truncate(outputdata.DataString, l.options.MaxSize)
+				outputdata.RawData = []byte(stringsutil.Truncate(string(outputdata.RawData), l.options.MaxSize))
 			}
 
 			for _, store := range l.Store {
@@ -149,8 +154,8 @@ func (l *Logger) LogRequest(req *http.Request, userdata types.UserData) error {
 		}
 		l.jsonLogMap.Store(userdata.ID, outputData)
 	}
-	if (!l.options.OutputJsonl) && (l.options.OutputFolder != "" || l.options.Kafka.Addr != "" || l.options.Elastic.Addr != "") {
-		l.asyncqueue <- types.OutputData{Data: reqdump, Userdata: userdata}
+	if l.options.OutputFolder != "" {
+		l.asyncqueue <- types.OutputData{RawData: reqdump, Userdata: userdata}
 	}
 
 	if l.options.Verbosity >= types.VerbosityVeryVerbose {
@@ -181,6 +186,7 @@ func (l *Logger) LogResponse(resp *http.Response, userdata types.UserData) error
 	if err != nil {
 		return err
 	}
+	var data []byte
 	if l.options.OutputJsonl {
 		defer l.jsonLogMap.Delete(userdata.ID)
 		outputData := types.HTTPRequestResponseLog{}
@@ -195,14 +201,14 @@ func (l *Logger) LogResponse(resp *http.Response, userdata types.UserData) error
 		if err := fillJsonResponseData(resp, &outputData); err != nil {
 			return err
 		}
-		respdump, err = json.Marshal(outputData)
+		data, err = json.Marshal(outputData)
 		if err != nil {
 			return err
 		}
 	}
-	if l.options.OutputFolder != "" || l.options.Kafka.Addr != "" || l.options.Elastic.Addr != "" {
-		l.asyncqueue <- types.OutputData{Data: respdump, Userdata: userdata}
-	}
+
+	l.asyncqueue <- types.OutputData{RawData: respdump, Data: data, Userdata: userdata}
+
 	if l.options.Verbosity >= types.VerbosityVeryVerbose {
 		contentType := resp.Header.Get("Content-Type")
 		bodyBytes := bytes.TrimPrefix(respdump, respdumpNoBody)
